import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Random;
import java.util.Scanner;

public class Lotto {
	private static final int UPPER_BOUND = 49;
	private static final int SAMPLE_SIZE = 6;
	private static final int SAMPLE_COUNT = 8;
	
	private static Random r;
	
	private static int matches(int[] set1, int[] set2) {
		int j = 0, count = 0;
		for (int i = 0; i < SAMPLE_SIZE; i++) {
			while (set1[i] > set2[j] && j < SAMPLE_SIZE - 1) j++;
			if (j >= SAMPLE_SIZE - 1 && set1[i] > set2[j]) break;
			if (set1[i] == set2[j]) count++;
		}
		return count;
	}
	
	private static void mybet(int[] output) {
		boolean[] bitfield = new boolean[UPPER_BOUND];
		for (int i = 0; i < SAMPLE_SIZE; i++) {
			int pos = -1;
			int j = r.nextInt(UPPER_BOUND - i) + 1;
			while (j > 0) {
				pos++;
				if (!bitfield[pos]) j--;
			}
			bitfield[pos] = true;
		}
		int pos = 0;
		for (int i = 0; i < UPPER_BOUND; i++) {
			if (bitfield[i]) output[pos++] = i + 1;
		}
	}
	
	public static void main(String[] args) throws IOException, ParseException {
		String buf, datestr, fullday;
		SimpleDateFormat dparser, dformatter;
		Date midnighttime;
		int[] lotto = new int[SAMPLE_SIZE];
		int[] mylotto = new int[SAMPLE_SIZE];
		BufferedReader f;

		r = new Random();
		dparser = new SimpleDateFormat("dd.MM.yyyy");
		dformatter = new SimpleDateFormat("EE dd.MM.yyyy");
		
		f = new BufferedReader(new FileReader("lotto.txt"));
		while ((buf = f.readLine()) != null) {
			Scanner sc = new Scanner(buf);
			sc.skip("[1-9]\\d*\t");
			datestr = sc.next();
			for (int i = 0; i < SAMPLE_SIZE; i++) {
				lotto[i] = sc.nextInt();
			}
			midnighttime = dparser.parse(datestr);
			fullday = dformatter.format(midnighttime);
			r.setSeed(midnighttime.getTime());
			int maxmatches = 0, maxmatchcount = 0;
			for (int i = 0; i < SAMPLE_COUNT; i++) {
				mybet(mylotto);
				int curmatches = matches(lotto, mylotto);
				if (curmatches > maxmatches) {
					maxmatches = curmatches;
					maxmatchcount = 1;
				} else if (curmatches == maxmatches) {
					maxmatchcount++;
				}
			}
			System.out.format("%s: %d Richtige", fullday, maxmatches);
			if (maxmatches > 0 && maxmatchcount > 1) {
				System.out.format(" (%d Mal)%n", maxmatchcount);
			} else {
				System.out.println();
			}
		}
		f.close();
	}
}
